package
Version:
v0.0.0-...-b313c08
Opens a new window with list of versions in this module.
Published: Feb 8, 2024
License: GPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type User struct {
gorm.Model
ID string `gorm:"primaryKey"`
Email string `gorm:"unique" binding:"required"`
Password string `binding:"required"`
Events []Event
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.